@@ -1,7 +1,7 @@
 use rtrend::{Client, Country, Keywords, RegionInterest};
 
 fn main() {
-    let country = Country::new("US");
+    let country = Country::US;
     let keywords = Keywords::new(vec!["Instagram", "Facebook", "Pinterest"]);
     
     let client = Client::new(keywords, country).build();
