@@ -4,6 +4,7 @@ use crate::{utils, Category, Cookie, Country, Keywords, Lang, Property};
 use chrono::{Date, Utc};
 use reqwest::{blocking::ClientBuilder, header, Url};
 use serde_json::Value;
+use strum::EnumProperty;
 
 #[derive(Clone, Debug)]
 pub struct Client {
@@ -18,14 +19,14 @@ pub struct Client {
     pub response: Value,
 }
 
-/// Default value for client 
-/// 
+/// Default value for client
+///
 /// Returns a Default Client.  
 ///
 /// By default,
 /// - The requested period is 1 year
 /// - The Country is all the countries supported by google trend
-/// - The Langage is English 
+/// - The Langage is English
 /// - The Category is 0
 /// - The response is empty (but valid json)
 ///
@@ -33,24 +34,24 @@ pub struct Client {
 /// ```
 /// # use rtrend::{Client, Keywords, Country};
 /// let keywords = Keywords::new(vec!["rust"]);
-/// let country = Country::new("FR");
-/// 
+/// let country = Country::FR;
+///
 /// let client = Client::new(keywords, country);
-/// 
+///
 /// println!("{:#?}", client);
 /// ```
 impl Default for Client {
-    fn default() -> Client {
-        Client {
-            client: Default::default(),
+    fn default() -> Self {
+        Self {
+            client: reqwest::blocking::Client::default(),
             cookie: Cookie::new(),
             response: serde_json::from_str("{}").unwrap(),
-            keywords: Default::default(),
+            keywords: Keywords::default(),
             time: "today 12-m".to_string(),
-            country: Country::new("ALL"),
-            property: Property::new("web"),
-            lang: Lang::new("en"),
-            category: Category::new(0),
+            country: Country::ALL,
+            property: Property::Web,
+            lang: Lang::EN,
+            category: Category::All,
         }
     }
 }
@@ -67,10 +68,15 @@ impl Client {
     /// ```
     /// # use rtrend::{Client, Keywords, Country};
     /// let keywords = Keywords::new(vec!["rust"]);
-    /// let country = Country::new("FR");
-    /// 
+    /// let country = Country::FR;
+    ///
     /// let client = Client::new(keywords, country);
     /// ```
+    ///
+    /// # Panics
+    ///
+    /// Will panic if the client can't be built.
+    /// This can happen if the cookie can not be set or if the request time out.
     pub fn new(keywords: Keywords, country: Country) -> Self {
         let mut headers = header::HeaderMap::new();
         headers = Cookie::new().add_to_header(headers);
@@ -87,7 +93,7 @@ impl Client {
             client,
             country,
             keywords,
-            ..Default::default()
+            ..Client::default()
         }
     }
 
@@ -99,7 +105,7 @@ impl Client {
     /// ```
     /// # use rtrend::{Client, Keywords, Country};
     /// let keywords = Keywords::new(vec!["rust"]);
-    /// let country = Country::new("FR");
+    /// let country = Country::FR;
     /// let client = Client::new(keywords, country);
     ///
     /// // ...
@@ -121,9 +127,9 @@ impl Client {
     /// ```
     /// # use rtrend::{Client, Keywords, Country, Lang};
     /// let keywords = Keywords::new(vec!["rust"]);
-    /// let country = Country::new("ALL");
-    /// let lang = Lang::new("fr");
-    /// 
+    /// let country = Country::ALL;
+    /// let lang = Lang::FR;
+    ///
     /// // Set response langage to french
     /// let client = Client::new(keywords, country).with_lang(lang);
     /// ```
@@ -142,9 +148,9 @@ impl Client {
     /// ```
     /// # use rtrend::{Client, Keywords, Country, Category};
     /// let keywords = Keywords::new(vec!["hacking"]);
-    /// let country = Country::new("ALL");
-    /// let category = Category::new(231);
-    /// 
+    /// let country = Country::ALL;
+    /// let category = Category::EngineeringAndTechnology;
+    ///
     /// // Set category to "Engineering & Technology"
     /// let client = Client::new(keywords, country).with_category(category);
     /// ```
@@ -165,11 +171,11 @@ impl Client {
     /// ```
     /// # use rtrend::{Client, Keywords, Country, Property};
     /// let keywords = Keywords::new(vec!["vlog"]);
-    /// let country = Country::new("ALL");
-    /// 
+    /// let country = Country::ALL;
+    ///
     /// // The response will be retrieve from youtube data
-    /// let property = Property::new("youtube");
-    /// 
+    /// let property = Property::Youtube;
+    ///
     /// let client = Client::new(keywords, country).with_property(property);
     /// ```
     pub fn with_property(mut self, property: Property) -> Self {
@@ -188,8 +194,8 @@ impl Client {
     /// ```
     /// # use rtrend::{Client, Keywords, Country};
     /// let keywords = Keywords::new(vec!["vlog"]);
-    /// let country = Country::new("ALL");
-    /// 
+    /// let country = Country::ALL;
+    ///
     /// // response will concern data from this week
     /// let client = Client::new(keywords, country).with_period("now 7d".to_string());
     /// ```
@@ -208,12 +214,12 @@ impl Client {
     /// # use rtrend::{Client, Keywords, Country};
     /// # use chrono::prelude::*;
     /// let keywords = Keywords::new(vec!["vlog"]);
-    /// let country = Country::new("ALL");
-    /// 
+    /// let country = Country::ALL;
+    ///
     /// // response will concern data from April 25, 2020 to July 30, 2021
     /// let start_date: Date<Utc> = Utc.ymd(2017, 4, 25);
     /// let end_date: Date<Utc> = Utc.ymd(2020, 7, 30);
-    /// 
+    ///
     /// let client = Client::new(keywords, country).with_date(start_date, end_date);
     /// ```
     pub fn with_date(mut self, start_date: Date<Utc>, end_date: Date<Utc>) -> Self {
@@ -236,13 +242,13 @@ impl Client {
     /// ```
     /// # use rtrend::{Client, Keywords, Country, Property, Category, Lang};
     /// let keywords = Keywords::new(vec!["cat"]);
-    /// let country = Country::new("ALL");
-    /// 
+    /// let country = Country::ALL;
+    ///
     /// let client = Client::new(keywords, country).with_filter(
-    ///     Category::new(66),          // 66 => "Pets & Animal"
-    ///     Property::new("images"),    // Search on Google Images
+    ///     Category::PetsAndAnimals, 
+    ///     Property::Images,           // Search on Google Images
     ///     "today 3-m".to_string(),    // 90 previous days
-    ///     Lang::new("it")             // in italian
+    ///     Lang::IT                    // in italian
     /// );
     /// ```
     #[allow(dead_code)]
@@ -269,8 +275,8 @@ impl Client {
     /// ```
     /// # use rtrend::{Client, Keywords, Country};
     /// let keywords = Keywords::new(vec!["Cat"]);
-    /// let country = Country::new("US");
-    /// 
+    /// let country = Country::US;
+    ///
     /// let client = Client::new(keywords, country).build();
     ///
     /// println!("{}", client.response);
@@ -283,8 +289,8 @@ impl Client {
             .client
             .get(url)
             .query(&[
-                ("hl", self.lang.as_str()),
-                ("geo", self.country.as_str()),
+                ("hl", self.lang.to_string().as_str()),
+                ("geo", self.country.to_string().as_str()),
                 ("tz", "-120"),
                 ("req", &comparison_item),
                 ("tz", "-120"),
@@ -320,10 +326,16 @@ impl Client {
             comparison_item.push_str(&index_value);
         }
 
+
+        let id = match self.category.get_int("Id") {
+            Some(id) => id,
+            None => 0
+        };
+
         format!(
             "{{ 'comparisonItem': [{}], 'category':{}, 'property':'{}' }}",
             comparison_item.as_str(),
-            self.category,
+            id,
             self.property
         )
     }
